==> deepin-deb-installer_1.2.9.orig.tar.gz: deepin-deb-installer-1.2.9/translations/deepin-deb-installer_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="62"/>
        <source>Dark Theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="88"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin Package Manager</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="293"/>
        <source>Bulk Install</source>
        <translation>Instalação em Volume</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>A instalação falhou, por favor, verifique a sua ligação à Internet</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>A instalação falhou, por favor, verifique as atualizações no &apos;Centro de Controlo&apos;</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Instalação falhou, espaço insuficiente em disco</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Instalação falhou</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Dependências com problemas: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Arquitetura do pacote não compatível</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="52"/>
        <source>Drag and drop file here</source>
        <translation>Arraste e largue aqui o ficheiro</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="76"/>
        <source>Select File</source>
        <translation>Selecionar Ficheiro</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Mostrar detalhes</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="111"/>
        <source>Installing</source>
        <translation>A Instalar</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="115"/>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="119"/>
        <source>Failed</source>
        <translation>Falhou</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="144"/>
        <source>Same version installed</source>
        <translation>A mesma versão já está instalada</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="147"/>
        <source>Other version installed: %1</source>
        <translation>Outra versão instalada: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Collapse</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Display details</source>
        <translation>Exibir detalhes</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="141"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="143"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="145"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="147"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="149"/>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="151"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="164"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="320"/>
        <source>Installed successfully</source>
        <translation>Instalado com sucesso</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="322"/>
        <source>Uninstalled successfully</source>
        <translation>Desinstalado com sucesso</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="389"/>
        <source>Other version installed: %1</source>
        <translation>Outra versão instalada: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="333"/>
        <source>Uninstall Failed</source>
        <translation>A desinstalação falhou</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="159"/>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="387"/>
        <source>Same version installed</source>
        <translation>A mesma versão já está instalada</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Mostrar pacotes relacionados</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Tem a certeza que deseja desinstalar %1?
Também serão removidas todas as dependências</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin Package Manager</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>O Deepin Package Manager é uma aplicação utilizada para ajudar os utilizadores a instalar e remover software local, suporta instalações em massa.</translation>
    </message>
</context>
</TS>

==> deepin-deb-installer_5.0.0.orig.tar.gz: deepin-deb-installer-5.0.0/translations/deepin-deb-installer_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="62"/>
        <source>Dark theme</source>
        <translation>Tema escuro</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="88"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin Package Manager</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="293"/>
        <source>Bulk Install</source>
        <translation>Instalação em Volume</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>A instalação falhou, por favor, verifique a sua ligação à Internet</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>A instalação falhou, por favor, verifique as atualizações no Centro de Controlo</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Instalação falhou, espaço insuficiente no disco</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Instalação falhou</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Dependências com problemas: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Arquitetura do pacote não compatível</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="52"/>
        <source>Drag and drop file here</source>
        <translation>Arraste e largue aqui o ficheiro</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="76"/>
        <source>Select File</source>
        <translation>Selecionar Ficheiro</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Colapso</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Exibir detalhes</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="111"/>
        <source>Installing</source>
        <translation>A Instalar</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="115"/>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="119"/>
        <source>Failed</source>
        <translation>Falhou</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="144"/>
        <source>Same version installed</source>
        <translation>A mesma versão já está instalada</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="147"/>
        <source>Other version installed: %1</source>
        <translation>Outra versão instalada: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Collapse</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Display details</source>
        <translation>Exibir detalhes</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="141"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="143"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="145"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="147"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="149"/>
        <source>Back</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="151"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="164"/>
        <source>Version: </source>
        <translation>Versão:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="320"/>
        <source>Installed successfully</source>
        <translation>Instalado com sucesso</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="322"/>
        <source>Uninstalled successfully</source>
        <translation>Desinstalado com sucesso</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="389"/>
        <source>Other version installed: %1</source>
        <translation>Outra versão instalada: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="333"/>
        <source>Uninstall Failed</source>
        <translation>A desinstalação falhou</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="159"/>
        <source>Name: </source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="387"/>
        <source>Same version installed</source>
        <translation>A mesma versão já está instalada</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Mostrar pacotes relacionados</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Confirmar</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>Tem a certeza que deseja desinstalar %1?
Também serão removidas todas as dependências</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin Package Manager</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is used to help users install and remove local packages, supporting bulk install.</source>
        <translation>O Deepin Package Manager é uma aplicação utilizada para ajudar os utilizadores a instalar e remover pacotes locais, suporta instalações em massa.</translation>
    </message>
</context>
</TS>
